extern char *us_ups_pricing_name[];
extern void ups_load_rates(void);
extern char *us_ups_zone_to_price(char *, int, char *, int eas);
extern void ups_world_load(void);
extern void ups_parcel_types(void);
extern void ups_country_load(void);
extern void world_ups_parcel_types(void);
extern int ups_country_zone(struct csv_table **, int *, char *, char *, char *);
extern char *ups_world_pricing(struct csv_table *, int, int, int, char *, char *, char *, char *);
extern char *get_zone_ca(const char *state_in, const char *pcode, int type, int *eas);
extern char *canada_price_for(int service, float weight, char *zone);
extern char *canada_eas(float weight, char *price);
extern float ups_world_eas_check(char *country, char *place, char *pcode, float weight);
extern void ups_load_canada(void);

extern char *uncomma(char *x);


#define PORT	5515		/* Socket port */

/*
 *	Socket I/O
 */
 
extern void sock_printf(const char *, ...);
extern int sock_gets(char *, int);
extern void set_socket_fd(int fd);
